To navigate a navigable navigable to a URL url using an optional `Document`-or-null sourceDocument (default null), with an optional POST resource, string, or null documentResource (default null), an optional boolean exceptionsEnabled (default false):

1. Let sourceSnapshotParams be the result of snapshotting source snapshot params given sourceDocument.

2. Assert: documentResource is null if and only if response is null.

3. Let traverseQueue be a new session history traversal queue.

4. Append the following session history traversal queue steps to traverseQueue:

   1. Let changingNavigableContinuation be the result of starting an unload given sourceSnapshotParams.

   2. Queue a global task on the navigation and traversal task source given navigable's active window to run the remaining steps in parallel.

5. Append session history traversal steps to traverseQueue to finalize a cross-document navigation given navigable.